@@ -4,11 +4,12 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '1.001';
+our $VERSION = '1.002';
 
 use parent qw(ShipIt::Step);
 use Fatal qw(open close rename opendir closedir);
 use File::Find qw(find);
+use File::stat ();
 
 my $looks_like_perl = qr/\. p(?: [ml]c? | od | erl ) \z/xms;
 
@@ -94,9 +95,11 @@ sub run {
 
         close $out;
 
-        if($need_replace){
+        if($need_replace) {
+            my $mode = File::stat::stat($module)->mode;
             rename $module       => "$module~";
             rename "$module.tmp" => $module;
+            chmod $mode, $module;
 
             unlink "$module~";
         }
@@ -130,7 +133,7 @@ ShipIt::Step::ChangeAllVersions - Changes version information in all the modules
 
 =head1 VERSION
 
-This document describes ShipIt::Step::ChangeAllVersions version 1.001.
+This document describes ShipIt::Step::ChangeAllVersions version 1.002.
 
 =head1 SYNOPSIS
 
